
# Changelog

## Version 1.0.0 (14/06/2023)

- initial release

## Version 1.0.1 (20/06/2023)

 - added conversion functions:
	- percent (per hundred): `percent`, `perc`, `pc`
	- per mille (per thousand): `permille`, `pm`
	- per myriad (per ten thousand): `permyriad`, `bp`
	- per cent mille (per hundred thousand): `percentmille`, `pcm`
	- parts-per-million: `ppm`
	- parts-per-billion: `ppb`
	- parts-per-trillion: `ppt`
	- parts-per-quadrillion: `ppq`
